# -*- coding: utf-8 -*-

from .client import DQClient
from .job import JobConfig

__author__ = """Mikołaj Olszewski"""
__email__ = 'mikolaj.olszewski@algolytics.pl'
__version__ = '0.1.0'

__all__ = ['DQClient', 'JobConfig']
